@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2018 Laurent Montel <montel@kde.org>
+    Copyright (c) 2013-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -24,11 +24,7 @@
 #include <Collection>
 #include <QModelIndex>
 #include <QIdentityProxyModel>
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-class KRecursiveFilterProxyModel;
-#else
 class QSortFilterProxyModel;
-#endif
 namespace Akonadi {
 class EntityTreeModel;
 class ChangeRecorder;
@@ -73,11 +69,7 @@ private:
     QTreeView *mFolderView = nullptr;
     Akonadi::EntityTreeModel *mModel = nullptr;
     Akonadi::ChangeRecorder *mChangeRecorder = nullptr;
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    KRecursiveFilterProxyModel *mCollectionFilter = nullptr;
-#else
     QSortFilterProxyModel *mCollectionFilter = nullptr;
-#endif
     NewMailNotifierCollectionProxyModel *mNewMailNotifierProxyModel = nullptr;
 };
 
