@@ -27,9 +27,7 @@
 #include <KNotifyConfigWidget>
 #include <QLineEdit>
 #include <QPushButton>
-#include <KHelpMenu>
 #include <kaboutdata.h>
-#include <QIcon>
 
 #include <QTabWidget>
 #include <QCheckBox>
@@ -37,10 +35,8 @@
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QWhatsThis>
-#include <QAction>
 
 #include <KSharedConfig>
-#include <KConfigGroup>
 
 static const char *textToSpeakMessage
     = I18N_NOOP("<qt>"
@@ -178,6 +174,7 @@ void NewMailNotifierSettingsWidget::load()
 
 bool NewMailNotifierSettingsWidget::save() const
 {
+    mSelectCollection->updateCollectionsRecursive();
     auto settings = NewMailNotifierAgentSettings::self();
     settings->setShowPhoto(mShowPhoto->isChecked());
     settings->setShowFrom(mShowFrom->isChecked());
