@@ -39,8 +39,7 @@
 #include <KDAV/DavItemModifyJob>
 #include <KDAV/DavItemsFetchJob>
 #include <KDAV/DavItemsListJob>
-#include <KDAV/DavManager>
-#include <KDAV/DavProtocolBase>
+#include <KDAV/ProtocolInfo>
 
 #include <KCalendarCore/FreeBusy>
 #include <KCalendarCore/Incidence>
@@ -194,7 +193,8 @@ void DavGroupwareResource::configure(WId windowId)
         SetupWizard wizard;
 
         if (windowId) {
-            KWindowSystem::setMainWindow(&wizard, windowId);
+            wizard.setAttribute(Qt::WA_NativeWindow, true);
+            KWindowSystem::setMainWindow(wizard.windowHandle(), windowId);
         }
 
         const int result = wizard.exec();
@@ -227,7 +227,8 @@ void DavGroupwareResource::configure(WId windowId)
     ConfigDialog dialog;
 
     if (windowId) {
-        KWindowSystem::setMainWindow(&dialog, windowId);
+        dialog.setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(dialog.windowHandle(), windowId);
     }
 
     if (!Settings::self()->defaultUsername().isEmpty()) {
@@ -814,7 +815,7 @@ void DavGroupwareResource::onRetrieveItemsFinished(KJob *job)
 
     Collection collection = job->property("collection").value<Collection>();
     const KDAV::DavUrl davUrl = Settings::self()->davUrlFromCollectionUrl(collection.remoteId());
-    const bool protocolSupportsMultiget = KDAV::DavManager::self()->davProtocol(davUrl.protocol())->useMultiget();
+    const bool protocolSupportsMultiget = KDAV::ProtocolInfo::useMultiget(davUrl.protocol());
 
     const KDAV::DavItemsListJob *listJob = qobject_cast< KDAV::DavItemsListJob *>(job);
     auto cache = mEtagCaches.value(collection.remoteId());
