@@ -26,8 +26,7 @@ class EwsCreateCalendarJob : public EwsCreateItemJob
 {
     Q_OBJECT
 public:
-    EwsCreateCalendarJob(EwsClient &client, const Akonadi::Item &item,
-                         const Akonadi::Collection &collection, EwsTagStore *tagStore, EwsResource *parent);
+    EwsCreateCalendarJob(EwsClient &client, const Akonadi::Item &item, const Akonadi::Collection &collection, EwsTagStore *tagStore, EwsResource *parent);
     ~EwsCreateCalendarJob() override;
     bool setSend(bool send = true) override;
 protected:
