@@ -79,9 +79,9 @@ void EwsPKeyAuthJob::start()
         params[it.first.toLower()] = QUrl::fromPercentEncoding(it.second.toLatin1());
     }
 
-    if (params.contains(QStringLiteral("submiturl")) && params.contains(QStringLiteral("nonce"))
-        && params.contains(QStringLiteral("certauthorities")) && params.contains(QStringLiteral("context"))
-        && params.contains(QStringLiteral("version"))) {
+    if (params.contains(QLatin1String("submiturl")) && params.contains(QLatin1String("nonce"))
+        && params.contains(QLatin1String("certauthorities")) && params.contains(QLatin1String("context"))
+        && params.contains(QLatin1String("version"))) {
         const auto respToken = buildAuthResponse(params);
 
         if (!respToken.isEmpty()) {
@@ -113,7 +113,7 @@ void EwsPKeyAuthJob::authRequestFinished()
     if (mAuthReply->error() == QNetworkReply::NoError) {
         mResultUri = mAuthReply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
         if (!mResultUri.isValid()) {
-            setErrorMsg(QStringLiteral("Incorect or missing redirect URI in PKeyAuth response"));
+            setErrorMsg(QStringLiteral("Incorrect or missing redirect URI in PKeyAuth response"));
         }
     } else {
         setErrorMsg(QStringLiteral("Failed to process PKeyAuth request: %1").arg(mAuthReply->errorString()));
@@ -130,7 +130,7 @@ QByteArray EwsPKeyAuthJob::buildAuthResponse(const QMap<QString, QString> &param
         return QByteArray();
     }
 
-    if (params[QStringLiteral("version")] != QStringLiteral("1.0")) {
+    if (params[QStringLiteral("version")] != QLatin1String("1.0")) {
         setErrorMsg(QStringLiteral("Unknown version of PKey Authentication: %1").arg(params[QStringLiteral("version")]));
         return QByteArray();
     }
