@@ -104,7 +104,7 @@ EwsCreateFolderRequest::Response::Response(QXmlStreamReader &reader)
             return;
         }
 
-        if (reader.name() == QStringLiteral("Folders")) {
+        if (reader.name() == QLatin1String("Folders")) {
             if (reader.readNextStartElement()) {
                 EwsFolder folder(reader);
                 if (!folder.isValid()) {
