@@ -102,7 +102,7 @@ EwsMoveItemRequest::Response::Response(QXmlStreamReader &reader)
             return;
         }
 
-        if (reader.name() == QStringLiteral("Items")) {
+        if (reader.name() == QLatin1String("Items")) {
             if (reader.readNextStartElement()) {
                 EwsItem item(reader);
                 if (!item.isValid()) {
