@@ -377,7 +377,7 @@ bool EwsPropertyField::read(QXmlStreamReader &reader)
     bool ok;
 
     // First check the property type
-    if (reader.name() == QStringLiteral("FieldURI")) {
+    if (reader.name() == QLatin1String("FieldURI")) {
         if (!attrs.hasAttribute(QStringLiteral("FieldURI"))) {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Error reading property field - missing %1 attribute.")
                 .arg(QStringLiteral("FieldURI"));
@@ -385,7 +385,7 @@ bool EwsPropertyField::read(QXmlStreamReader &reader)
         }
         d->mPropType = Field;
         d->mUri = attrs.value(QStringLiteral("FieldURI")).toString();
-    } else if (reader.name() == QStringLiteral("IndexedFieldURI")) {
+    } else if (reader.name() == QLatin1String("IndexedFieldURI")) {
         if (!attrs.hasAttribute(QStringLiteral("FieldURI"))) {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Error reading property field - missing %1 attribute.")
                 .arg(QStringLiteral("FieldURI"));
@@ -413,7 +413,7 @@ bool EwsPropertyField::read(QXmlStreamReader &reader)
         d->mPropType = IndexedField;
         d->mUri = uri;
         d->mIndex = index;
-    } else if (reader.name() == QStringLiteral("ExtendedFieldURI")) {
+    } else if (reader.name() == QLatin1String("ExtendedFieldURI")) {
         if (!attrs.hasAttribute(QStringLiteral("PropertyType"))) {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Error reading property field - missing %1 attribute.")
                 .arg(QStringLiteral("PropertyType"));
