@@ -57,7 +57,9 @@ void EwsUnsubscribeRequest::start()
 bool EwsUnsubscribeRequest::parseResult(QXmlStreamReader &reader)
 {
     return parseResponseMessage(reader, QStringLiteral("Unsubscribe"),
-                                [this](QXmlStreamReader &reader) {return parseUnsubscribeResponse(reader);});
+                                [this](QXmlStreamReader &reader) {
+        return parseUnsubscribeResponse(reader);
+    });
 }
 
 bool EwsUnsubscribeRequest::parseUnsubscribeResponse(QXmlStreamReader &reader)
