@@ -67,7 +67,8 @@ EwsConfigDialog::EwsConfigDialog(EwsResource *parentResource, EwsClient &client,
     , mSettings(settings)
 {
     if (wId) {
-        KWindowSystem::setMainWindow(this, wId);
+        setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(windowHandle(), wId);
     }
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -120,9 +121,9 @@ EwsConfigDialog::EwsConfigDialog(EwsResource *parentResource, EwsClient &client,
     mSettings->requestPassword(false);
     mUi->authOAuth2RadioButton->setEnabled(true);
     const auto authMode = mSettings->authMode();
-    if (authMode == QStringLiteral("username-password")) {
+    if (authMode == QLatin1String("username-password")) {
         mUi->authUsernameRadioButton->setChecked(true);
-    } else if (authMode == QStringLiteral("oauth2")) {
+    } else if (authMode == QLatin1String("oauth2")) {
         mUi->authOAuth2RadioButton->setChecked(true);
         mUi->pkeyAuthGroupBox->setEnabled(true);
     }
