@@ -315,7 +315,7 @@ Collection EwsFetchFoldersJobPrivate::createFolderCollection(const EwsFolder &fo
         mimeTypes.append(KCalendarCore::Todo::todoMimeType());
         break;
     case EwsFolderTypeMail:
-        if (contClass == QStringLiteral("IPF.Note") || contClass.isEmpty()) {
+        if (contClass == QLatin1String("IPF.Note") || contClass.isEmpty()) {
             mimeTypes.append(KMime::Message::mimeType());
         }
         break;
