@@ -82,6 +82,8 @@ Q_SIGNALS:
 private:
     void compareItemLists();
     void syncTags();
+    bool processIncrementalRemoteItemUpdates(const EwsItem::List& items, QHash<QString, Akonadi::Item> &itemHash,
+                                             QHash<EwsItemType, Akonadi::Item::List> &toFetchItems);
 
     /*struct QueuedUpdateInt {
         QString changeKey;
@@ -98,7 +100,8 @@ private:
     EwsId::List mRemoteDeletedIds;
     QHash<EwsId, bool> mRemoteFlagChangedIds;
     int mPendingJobs;
-    unsigned mTotalItems;
+    unsigned mTotalItemsToFetch;
+    unsigned mTotalItemsFetched;
     QString mSyncState;
     bool mFullSync;
     QueuedUpdateHash mQueuedUpdates;
