@@ -24,9 +24,12 @@
 
 using namespace Akonadi;
 
-EwsModifyItemFlagsJob::EwsModifyItemFlagsJob(EwsClient &client, QObject *parent, const Item::List &items,
-        const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags)
-    : EwsJob(parent), mItems(items), mClient(client), mAddedFlags(addedFlags), mRemovedFlags(removedFlags)
+EwsModifyItemFlagsJob::EwsModifyItemFlagsJob(EwsClient &client, QObject *parent, const Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags)
+    : EwsJob(parent)
+    , mItems(items)
+    , mClient(client)
+    , mAddedFlags(addedFlags)
+    , mRemovedFlags(removedFlags)
 {
 }
 
@@ -42,7 +45,7 @@ void EwsModifyItemFlagsJob::itemModifyFinished(KJob *job)
         return;
     }
 
-    EwsModifyItemJob *req = qobject_cast<EwsModifyItemJob*>(job);
+    EwsModifyItemJob *req = qobject_cast<EwsModifyItemJob *>(job);
     if (!req) {
         setErrorText(QStringLiteral("Invalid EwsModifyItemJob job object"));
         emitResult();
@@ -78,7 +81,7 @@ void EwsModifyItemFlagsJob::start()
         if (!items[static_cast<EwsItemType>(type)].isEmpty()) {
             EwsItemHandler *handler = EwsItemHandler::itemHandler(static_cast<EwsItemType>(type));
             EwsModifyItemJob *job = handler->modifyItemJob(mClient, items[type],
-                                    QSet<QByteArray>() << "FLAGS", this);
+                                                           QSet<QByteArray>() << "FLAGS", this);
             connect(job, &EwsModifyItemJob::result, this, &EwsModifyItemFlagsJob::itemModifyFinished);
             addSubjob(job);
             job->start();
