@@ -19,9 +19,11 @@
 
 #include "ewsmodifyitemjob.h"
 
-EwsModifyItemJob::EwsModifyItemJob(EwsClient &client, const Akonadi::Item::List &items,
-                                   const QSet<QByteArray> &parts, QObject *parent)
-    : EwsJob(parent), mItems(items), mParts(parts), mClient(client)
+EwsModifyItemJob::EwsModifyItemJob(EwsClient &client, const Akonadi::Item::List &items, const QSet<QByteArray> &parts, QObject *parent)
+    : EwsJob(parent)
+    , mItems(items)
+    , mParts(parts)
+    , mClient(client)
 {
 }
 
@@ -29,8 +31,7 @@ EwsModifyItemJob::~EwsModifyItemJob()
 {
 }
 
-void EwsModifyItemJob::setModifiedFlags(const QSet<QByteArray> &addedFlags,
-                                        const QSet<QByteArray> &removedFlags)
+void EwsModifyItemJob::setModifiedFlags(const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags)
 {
     mAddedFlags = addedFlags;
     mRemovedFlags = removedFlags;
