@@ -31,7 +31,8 @@
 using namespace Akonadi;
 
 EwsMtaResource::EwsMtaResource(const QString &id)
-    : Akonadi::ResourceBase(id), mEwsResource(nullptr)
+    : Akonadi::ResourceBase(id)
+    , mEwsResource(nullptr)
 {
 }
 
