@@ -220,7 +220,7 @@ void EwsResource::rootFolderFetchFinished(KJob *job)
         job->setProperty("inboxId", id.id());
         connect(job, &CollectionFetchJob::result, this, &EwsResource::adjustInboxRemoteIdFetchFinished);
 
-        int inboxIdx = mSettings->serverSubscriptionList().indexOf(QStringLiteral("INBOX"));
+        int inboxIdx = mSettings->serverSubscriptionList().indexOf(QLatin1String("INBOX"));
         if (inboxIdx >= 0) {
             QStringList subList = mSettings->serverSubscriptionList();
             subList[inboxIdx] = id.id();
@@ -234,7 +234,7 @@ void EwsResource::rootFolderFetchFinished(KJob *job)
         mRootCollection.setRemoteId(id.id());
         mRootCollection.setRemoteRevision(id.changeKey());
         qCDebug(EWSRES_LOG) << "Root folder is " << id;
-        Q_EMIT status(Idle, i18nc("@info:status Resource is ready", "Ready"));
+        emitReadyStatus();
 
         if (mSettings->serverSubscription()) {
             mSubManager.reset(new EwsSubscriptionManager(mEwsClient, id, mSettings.data(), this));
@@ -337,10 +337,6 @@ void EwsResource::connectionError()
 
 void EwsResource::retrieveItems(const Collection &collection)
 {
-    Q_EMIT status(1, QStringLiteral("Retrieving item list"));
-
-    Q_EMIT status(Running, i18nc("@info:status", "Retrieving %1 items", collection.name()));
-
     QString rid = collection.remoteId();
     EwsFetchItemsJob *job = new EwsFetchItemsJob(collection, mEwsClient,
                                                  mSyncState.value(rid), mItemsToCheck.value(rid), mTagStore, this);
@@ -460,7 +456,7 @@ void EwsResource::configure(WId windowId)
 
 void EwsResource::fetchFoldersJobFinished(KJob *job)
 {
-    Q_EMIT status(Idle, i18nc("@info:status The resource is ready", "Ready"));
+    emitReadyStatus();
     EwsFetchFoldersJob *req = qobject_cast<EwsFetchFoldersJob *>(job);
     if (!req) {
         qCWarning(EWSRES_LOG) << QStringLiteral("Invalid EwsFetchFoldersJob job object");
@@ -483,7 +479,7 @@ void EwsResource::fetchFoldersJobFinished(KJob *job)
 
 void EwsResource::fetchFoldersIncrJobFinished(KJob *job)
 {
-    Q_EMIT status(Idle, i18nc("@info:status The resource is ready", "Ready"));
+    emitReadyStatus();
     EwsFetchFoldersIncrJob *req = qobject_cast<EwsFetchFoldersIncrJob *>(job);
     if (!req) {
         qCWarning(EWSRES_LOG) << QStringLiteral("Invalid EwsFetchFoldersIncrJob job object");
@@ -505,7 +501,9 @@ void EwsResource::fetchFoldersIncrJobFinished(KJob *job)
     saveState();
     collectionsRetrievedIncremental(req->changedFolders(), req->deletedFolders());
 
-    fetchSpecialFolders();
+    if (!req->changedFolders().isEmpty() || !req->deletedFolders().isEmpty()) {
+        fetchSpecialFolders();
+    }
 }
 
 void EwsResource::itemFetchJobFinished(KJob *job)
@@ -536,7 +534,7 @@ void EwsResource::itemFetchJobFinished(KJob *job)
     }
     saveState();
     mItemsToCheck.remove(fetchJob->collection().remoteId());
-    Q_EMIT status(Idle, i18nc("@info:status The resource is ready", "Ready"));
+    emitReadyStatus();
 }
 
 void EwsResource::itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers)
@@ -1402,4 +1400,10 @@ void EwsResource::requestAuthFailed()
     }
 }
 
+void EwsResource::emitReadyStatus()
+{
+    Q_EMIT status(Idle, i18nc("@info:status Resource is ready", "Ready"));
+    Q_EMIT percent(0);
+}
+
 AKONADI_RESOURCE_MAIN(EwsResource)
