@@ -37,7 +37,7 @@ IsolatedTestBase::IsolatedTestBase(QObject *parent)
     : QObject(parent)
     , mFakeServerThread(new FakeEwsServerThread(this))
 {
-    qsrand(QDateTime::currentDateTimeUtc().toTime_t());
+    qsrand(QDateTime::currentDateTimeUtc().toMSecsSinceEpoch());
 }
 
 IsolatedTestBase::~IsolatedTestBase()
@@ -334,7 +334,7 @@ ValidateFolderIdsDialogEntry::ValidateFolderIdsDialogEntry(const QStringList &id
     QString responseXml;
     int folderIndex = 0;
 
-    for (auto folderId : ids) {
+    for (const auto &folderId : ids) {
         xQueryFolderIds.append(QStringLiteral("//m:GetFolder/m:FolderIds/t:FolderId[position()=%1 and @Id=\"%2\"]")
                                .arg(++folderIndex).arg(folderId));
         responseXml += QStringLiteral("<m:GetFolderResponseMessage ResponseClass=\"Success\">");
