@@ -21,7 +21,7 @@
 
 #include <QUrl>
 #include <QUrlQuery>
-
+#include <qtwebenginewidgetsversion.h>
 Q_LOGGING_CATEGORY(EWSCLI_LOG, "org.kde.pim.ews.client", QtInfoMsg)
 
 namespace Mock {
@@ -76,12 +76,17 @@ void QWebEngineProfile::setHttpUserAgent(const QString &ua)
 {
     mUserAgent = ua;
 }
-
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
 void QWebEngineProfile::setRequestInterceptor(QWebEngineUrlRequestInterceptor *interceptor)
 {
     mInterceptor = interceptor;
 }
-
+#else
+void QWebEngineProfile::setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor *interceptor)
+{
+    mInterceptor = interceptor;
+}
+#endif
 void QWebEngineProfile::installUrlSchemeHandler(QByteArray const &scheme, QWebEngineUrlSchemeHandler *handler)
 {
     mScheme = QString::fromLatin1(scheme);
