@@ -47,7 +47,8 @@ GoogleSettingsDialog::GoogleSettingsDialog(GoogleAccountManager *accountManager,
     , m_parentResource(parent)
     , m_accountManager(accountManager)
 {
-    KWindowSystem::setMainWindow(this, wId);
+    setAttribute(Qt::WA_NativeWindow, true);
+    KWindowSystem::setMainWindow(windowHandle(), wId);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
