@@ -12,7 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef GOOGLE_CONTACTS_CONTACTSRESOURCE_H
@@ -37,7 +37,7 @@ public:
     using GoogleResource::collectionChanged; // So we don't trigger -Woverloaded-virtual
     explicit ContactsResource(const QString &id);
 
-    ~ContactsResource();
+    ~ContactsResource() override;
 
 protected:
     using ResourceBase::retrieveItems; // Suppress -Woverload-virtual
