@@ -26,8 +26,7 @@
 #include <cachepolicy.h>
 #include <entitydisplayattribute.h>
 #include <akonadi/kmime/messageparts.h>
-#include <KLocalizedString>
-
+#include <QTest>
 class TestRetrieveCollectionsTask : public ImapTestBase
 {
     Q_OBJECT
@@ -405,7 +404,7 @@ private:
         // If the folder is the Inbox, make some special settings.
         if (pathPart.compare(QLatin1String("INBOX"), Qt::CaseInsensitive) == 0) {
             Akonadi::EntityDisplayAttribute *attr = new Akonadi::EntityDisplayAttribute;
-            attr->setDisplayName(i18n("Inbox"));
+            attr->setDisplayName(QStringLiteral("Inbox"));
             attr->setIconName(QStringLiteral("mail-folder-inbox"));
             collection.addAttribute(attr);
         }
@@ -413,7 +412,7 @@ private:
         // If the folder is the user top-level folder, mark it as well, even although it is not officially noted in the RFC
         if ((pathPart.compare(QLatin1String("user"), Qt::CaseInsensitive) == 0) && isNoSelect) {
             Akonadi::EntityDisplayAttribute *attr = new Akonadi::EntityDisplayAttribute;
-            attr->setDisplayName(i18n("Shared Folders"));
+            attr->setDisplayName(QStringLiteral("Shared Folders"));
             attr->setIconName(QStringLiteral("x-mail-distribution-list"));
             collection.addAttribute(attr);
         }
