@@ -264,7 +264,8 @@ int ImapResourceBase::configureSubscription(qlonglong windowId)
 
     mSubscriptions = new SubscriptionDialog(nullptr, SubscriptionDialog::AllowToEnableSubscription);
     if (windowId) {
-        KWindowSystem::setMainWindow(mSubscriptions, windowId);
+        mSubscriptions->setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(mSubscriptions->windowHandle(), windowId);
     }
     mSubscriptions->setWindowTitle(i18nc("@title:window", "Serverside Subscription"));
     mSubscriptions->setWindowIcon(QIcon::fromTheme(QStringLiteral("network-server")));
