@@ -41,8 +41,6 @@
 
 RetrieveCollectionMetadataTask::RetrieveCollectionMetadataTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
     : ResourceTask(CancelIfNoSession, resource, parent)
-    , m_pendingMetaDataJobs(0)
-    , m_session(nullptr)
 {
 }
 
