@@ -23,7 +23,7 @@
 class XMLObjectTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void testEvent();
     void testDontCrash();
 };
