@@ -179,19 +179,19 @@ const char *signingPreferenceToString(SigningPreference pref)
 
 SigningPreference stringToSigningPreference(const QString &str)
 {
-    if (str == QStringLiteral("never")) {
+    if (str == QLatin1String("never")) {
         return NeverSign;
     }
-    if (str == QStringLiteral("always")) {
+    if (str == QLatin1String("always")) {
         return AlwaysSign;
     }
-    if (str == QStringLiteral("alwaysIfPossible")) {
+    if (str == QLatin1String("alwaysIfPossible")) {
         return AlwaysSignIfPossible;
     }
-    if (str == QStringLiteral("askAlways")) {
+    if (str == QLatin1String("askAlways")) {
         return AlwaysAskForSigning;
     }
-    if (str == QStringLiteral("askWhenPossible")) {
+    if (str == QLatin1String("askWhenPossible")) {
         return AskSigningWheneverPossible;
     }
     return UnknownSigningPreference;
@@ -729,11 +729,11 @@ Kolab::Contact fromKABC(const KContacts::Addressee &addressee)
     }
     //TODO
     // c.setGender(addressee.gender());
-    std::vector<std::string> langages;
+    std::vector<std::string> languages;
     foreach (const KContacts::Lang &n, addressee.langs()) {
-        langages.push_back(toStdString(n.language()));
+        languages.push_back(toStdString(n.language()));
     }
-    c.setLanguages(langages);
+    c.setLanguages(languages);
 
     std::vector <Kolab::Telephone> phones;
     prefNum = -1;
