@@ -78,7 +78,7 @@ void ErrorHandler::addError(ErrorHandler::Severity s, const QString &message, co
     if (!lst.isEmpty()) {
         filename = lst.last();
     }
-    const QString output = QTime::currentTime().toString(QStringLiteral("(hh:mm:ss) ")) + filename + QLatin1String(":\t") + message;
+    const QString output = QTime::currentTime().toString(QLatin1String("(hh:mm:ss) ")) + filename + QLatin1String(":\t") + message;
     std::cout << output.toStdString() << std::endl;
     if (s == Debug) {
         return;
