@@ -34,7 +34,7 @@
 #ifndef KOLABV2_NOTE_H
 #define KOLABV2_NOTE_H
 
-#include <kcalcore/journal.h>
+#include <kcalendarcore/journal.h>
 
 #include "kolabbase.h"
 
@@ -43,7 +43,7 @@ class QDomElement;
 namespace KolabV2 {
 /**
  * This class represents a note, and knows how to load/save it
- * from/to XML, and from/to a KCalCore::Journal.
+ * from/to XML, and from/to a KCalendarCore::Journal.
  * The instances of this class are temporary, only used to convert
  * one to the other.
  */
@@ -52,16 +52,16 @@ class Note : public KolabBase
 public:
     /// Use this to parse an xml string to a journal entry
     /// The caller is responsible for deleting the returned journal
-    static KCalCore::Journal::Ptr xmlToJournal(const QString &xml);
+    static KCalendarCore::Journal::Ptr xmlToJournal(const QString &xml);
 
     /// Use this to get an xml string describing this journal entry
-    static QString journalToXML(const KCalCore::Journal::Ptr &);
+    static QString journalToXML(const KCalendarCore::Journal::Ptr &);
 
     /// Create a note object and
-    explicit Note(const KCalCore::Journal::Ptr &journal = KCalCore::Journal::Ptr());
+    explicit Note(const KCalendarCore::Journal::Ptr &journal = KCalendarCore::Journal::Ptr());
     virtual ~Note();
 
-    void saveTo(const KCalCore::Journal::Ptr &journal) const;
+    void saveTo(const KCalendarCore::Journal::Ptr &journal) const;
 
     QString type() const override
     {
@@ -94,10 +94,10 @@ public:
 
 protected:
     // Read all known fields from this ical incidence
-    void setFields(const KCalCore::Journal::Ptr &);
+    void setFields(const KCalendarCore::Journal::Ptr &);
 
     // Save all known fields into this ical incidence
-    void saveTo(const KCalCore::Incidence::Ptr &) const;
+    void saveTo(const KCalendarCore::Incidence::Ptr &) const;
 
     QString productID() const override;
 
