@@ -39,8 +39,7 @@ class UpdateMessageJob : public KJob
 {
     Q_OBJECT
 public:
-    UpdateMessageJob(const KMime::Message::Ptr &msg, KIMAP::Session *session, const QByteArray &kolabUid, const QSharedPointer<Merger> &merger, const QString &mailbox, qint64 uidNext = -1,
-                     qint64 oldUid = -1, QObject *parent = nullptr);
+    UpdateMessageJob(const KMime::Message::Ptr &msg, KIMAP::Session *session, const QByteArray &kolabUid, const QSharedPointer<Merger> &merger, const QString &mailbox, qint64 uidNext = -1, qint64 oldUid = -1, QObject *parent = nullptr);
 
     qint64 newUid() const;
 
