@@ -109,7 +109,7 @@ void CollectionFetchTest::testEmptyDir()
     // test base fetch of top level collection
     job = mStore->fetchCollections(mStore->topLevelCollection(), FileStore::CollectionFetchJob::Base);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(job->exec());
     QCOMPARE(job->error(), 0);
@@ -123,7 +123,7 @@ void CollectionFetchTest::testEmptyDir()
     // test first level fetch of top level collection
     job = mStore->fetchCollections(mStore->topLevelCollection(), FileStore::CollectionFetchJob::FirstLevel);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(job->exec());
     QCOMPARE(job->error(), 0);
@@ -136,7 +136,7 @@ void CollectionFetchTest::testEmptyDir()
     // test recursive fetch of top level collection
     job = mStore->fetchCollections(mStore->topLevelCollection(), FileStore::CollectionFetchJob::Recursive);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(job->exec());
     QCOMPARE(job->error(), 0);
@@ -154,7 +154,7 @@ void CollectionFetchTest::testEmptyDir()
 
     job = mStore->fetchCollections(collection, FileStore::CollectionFetchJob::Base);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(!job->exec());
     QCOMPARE(job->error(), (int)FileStore::Job::InvalidJobContext);
@@ -167,7 +167,7 @@ void CollectionFetchTest::testEmptyDir()
     // test fail of first level fetching non existent collection
     job = mStore->fetchCollections(collection, FileStore::CollectionFetchJob::FirstLevel);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(!job->exec());
     QCOMPARE(job->error(), (int)FileStore::Job::InvalidJobContext);
@@ -180,7 +180,7 @@ void CollectionFetchTest::testEmptyDir()
     // test fail of recursive fetching non existent collection
     job = mStore->fetchCollections(collection, FileStore::CollectionFetchJob::FirstLevel);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(!job->exec());
     QCOMPARE(job->error(), (int)FileStore::Job::InvalidJobContext);
@@ -272,7 +272,7 @@ void CollectionFetchTest::testMixedTree()
     // test base fetch of top level collection
     job = mStore->fetchCollections(mStore->topLevelCollection(), FileStore::CollectionFetchJob::Base);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(job->exec());
     QCOMPARE(job->error(), 0);
@@ -286,7 +286,7 @@ void CollectionFetchTest::testMixedTree()
     // test first level fetch of top level collection
     job = mStore->fetchCollections(mStore->topLevelCollection(), FileStore::CollectionFetchJob::FirstLevel);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(job->exec());
     QCOMPARE(job->error(), 0);
@@ -315,7 +315,7 @@ void CollectionFetchTest::testMixedTree()
     // test recursive fetch of top level collection
     job = mStore->fetchCollections(mStore->topLevelCollection(), FileStore::CollectionFetchJob::Recursive);
 
-    spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+    spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
     QVERIFY(job->exec());
     QCOMPARE(job->error(), 0);
@@ -354,7 +354,7 @@ void CollectionFetchTest::testMixedTree()
     Q_FOREACH (const Collection &collection, collections) {
         job = mStore->fetchCollections(collection, FileStore::CollectionFetchJob::Base);
 
-        spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+        spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
         QVERIFY(job->exec());
         QCOMPARE(job->error(), 0);
@@ -382,7 +382,7 @@ void CollectionFetchTest::testMixedTree()
     Q_FOREACH (const Collection &collection, collections) {
         job = mStore->fetchCollections(collection, FileStore::CollectionFetchJob::FirstLevel);
 
-        spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+        spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
         QVERIFY(job->exec());
         QCOMPARE(job->error(), 0);
@@ -428,7 +428,7 @@ void CollectionFetchTest::testMixedTree()
     Q_FOREACH (const Collection &collection, collections) {
         job = mStore->fetchCollections(collection, FileStore::CollectionFetchJob::Recursive);
 
-        spy = new QSignalSpy(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)));
+        spy = new QSignalSpy(job, &FileStore::CollectionFetchJob::collectionsReceived);
 
         QVERIFY(job->exec());
         QCOMPARE(job->error(), 0);
