@@ -33,7 +33,7 @@
 #include <KRandom>
 #include <QTemporaryDir>
 
-#include <qtest.h>
+#include <QTest>
 #include <QFileInfo>
 #include <QDir>
 
