@@ -38,7 +38,7 @@
 #include <KRandom>
 #include <QTemporaryDir>
 
-#include <qtest.h>
+#include <QTest>
 #include <QFileInfo>
 #include <QDir>
 #include <QCryptographicHash>
