@@ -26,9 +26,7 @@
 
 #include "folder.h"
 
-namespace OXA
-{
-
+namespace OXA {
 /**
  * @short A job that creates a new folder on the OX server.
  *
@@ -63,7 +61,6 @@ private Q_SLOTS:
 private:
     Folder mFolder;
 };
-
 }
 
 #endif
