@@ -27,12 +27,11 @@
 
 #include <kio/davjob.h>
 
-#include <QDebug>
-
 using namespace OXA;
 
 FolderDeleteJob::FolderDeleteJob(const Folder &folder, QObject *parent)
-    : KJob(parent), mFolder(folder)
+    : KJob(parent)
+    , mFolder(folder)
 {
 }
 
@@ -75,4 +74,3 @@ void FolderDeleteJob::davJobFinished(KJob *job)
 
     emitResult();
 }
-
