@@ -26,9 +26,7 @@
 
 #include "user.h"
 
-namespace OXA
-{
-
+namespace OXA {
 class UpdateUsersJob : public KJob
 {
     Q_OBJECT
@@ -50,7 +48,6 @@ private:
     User::List mUsers;
     qlonglong mUserId;
 };
-
 }
 
 #endif
