@@ -28,8 +28,7 @@
 #include <QObject>
 #include <QPointer>
 
-namespace KIO
-{
+namespace KIO {
 class Slave;
 class Job;
 class TransferJob;
@@ -69,7 +68,7 @@ private:
     QString authenticationToString(int type) const;
 
     QPointer<KIO::Slave> mSlave;
-    SlaveBaseJob *mCurrentJob;
+    SlaveBaseJob *mCurrentJob = nullptr;
     QString mPassword;
 };
 
@@ -93,8 +92,8 @@ protected:
     void startJob(const QString &path);
     virtual void connectJob();
 
-    KIO::TransferJob *mJob;
-    POPSession *mPOPSession;
+    KIO::TransferJob *mJob = nullptr;
+    POPSession *mPOPSession = nullptr;
 };
 
 class LoginJob : public SlaveBaseJob
